// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export {};//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/a22d00300655c17490ce63dffc28bcdcedcd82c4/node_modules/@azure/identity/dist/workerd/credentials/environmentCredentialOptions.js.map