// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export { randomUUID } from "./uuidUtils.common.js";//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/a22d00300655c17490ce63dffc28bcdcedcd82c4/node_modules/@typespec/ts-http-runtime/dist/react-native/util/uuidUtils.js.map