/*! @azure/msal-node v5.3.1 2026-06-30 */
'use strict';
/* eslint-disable header/header */
const name = "@azure/msal-node";
const version = "5.3.1";

export { name, version };
//# sourceMappingURL=packageMetadata.mjs.map
