// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export const SDK_VERSION = "1.22.3";
export const DEFAULT_RETRY_POLICY_COUNT = 3;//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/a22d00300655c17490ce63dffc28bcdcedcd82c4/node_modules/@azure/core-rest-pipeline/dist/react-native/constants.js.map