"use strict";
//
//  Copyright (c) Microsoft Corporation. All rights reserved.
//
Object.defineProperty(exports, "__esModule", { value: true });
exports.SshReportProgressEventArgs = void 0;
class SshReportProgressEventArgs {
    constructor(progress, sessionNumber) {
        this.progress = progress;
        this.sessionNumber = sessionNumber;
    }
    toString() {
        return `Progress: ${this.progress}` +
            this.sessionNumber ? ` Session number: ${this.sessionNumber}` : '';
    }
}
exports.SshReportProgressEventArgs = SshReportProgressEventArgs;
//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/a22d00300655c17490ce63dffc28bcdcedcd82c4/node_modules/@microsoft/dev-tunnels-ssh/events/sshReportProgressEventArgs.js.map