"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MappingError = void 0;
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */
class MappingError extends Error {
}
exports.MappingError = MappingError;
//# sourceMappingURL=types.js.map