// Copyright (c) Microsoft Corporation.
// Licensed under the MIT license.
export { AbortError } from "./AbortError.js";//# sourceMappingURL=https://main.vscode-cdn.net/sourcemaps/a22d00300655c17490ce63dffc28bcdcedcd82c4/node_modules/@azure/abort-controller/dist/browser/index.js.map